@@ -1,16 +1,18 @@
 # frozen_string_literal: true
 
+# :markup: markdown
+
 module ActionText
-  # Returns the currently loaded version of Action Text as a <tt>Gem::Version</tt>.
+  # Returns the currently loaded version of Action Text as a `Gem::Version`.
   def self.gem_version
     Gem::Version.new VERSION::STRING
   end
 
   module VERSION
     MAJOR = 7
-    MINOR = 0
-    TINY  = 10
-    PRE   = nil
+    MINOR = 2
+    TINY  = 2
+    PRE   = "1"
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
